from django.db import models
from common.models import Topic, Version, Section
# Create your models here.

class Namespace(models.Model):
    
    class Meta:
        ordering = ('name',)
        
    platform_section = models.ForeignKey(Section)
    name = models.CharField(max_length=64)
    display_name = models.CharField(max_length=64)
    
    def __unicode__(self):
        return self.name


class Element(models.Model):
    'Displayable API Element'
    
    class Meta:
        verbose_name = "Rendered Element"
        verbose_name_plural = "Rendered Elements"
        ordering = ('name',)
        
    name = models.CharField(max_length=64)
    description= models.CharField(max_length=256, blank=True, default='')
    namespace = models.ForeignKey(Namespace, blank=True, null=True)
    
    section = models.ForeignKey(Section)
    fullname = models.CharField(max_length=128)
    keywords = models.CharField(max_length=256, blank=True, default='')
    data = models.TextField()

    @property
    def platform_section(self):
        return self.section
        
    def __unicode__(self):
        return self.fullname


class Page(models.Model):
    'Displayable Page of non-Element content'
    
    class Meta:
        verbose_name = "Rendered Page"
        verbose_name_plural = "Rendered Pages"
        ordering = ('slug',)
        
    slug = models.CharField(max_length=64)
    title = models.CharField(max_length=64)
    description= models.CharField(max_length=256, blank=True, default='')
    namespace = models.ForeignKey(Namespace, blank=True, null=True)
    
    section = models.ForeignKey(Section)
    fullname = models.CharField(max_length=128)
    keywords = models.CharField(max_length=256, blank=True, default='')
    data = models.TextField()

    def __unicode__(self):
        return self.fullname


