/** 
 * @fileoverview A base JS object containing site-wide methods
 *
 * @author Canonical Web Team: Steve Edwards
 * @version 1.0
 */

template_dir = '/wp-content/themes/ubuntu-developer';
page_id = '';
base = {};

$(document).ready(function() {
	base.setPageId();
	base.positionNavArrow();
	base.readySearch();
	base.readyStepLinks();
	base.readyAccordion();
	base.readyFAQs();
	base.readySmoothScrolling();
	base.getTweets();
});

/* Init methods */

// Set the current page ID
base.setPageId = function() {
	page_id = base.getPageId();
};

// Position the arrow under the active nav item
base.positionNavArrow = function() {
	var item = $('.header-navigation li[class*="current"]');
	if (item.length !== 0) {
		var item_width = item.width();
		var item_pos = item.offset();
		var arrow = $('.arrow-nav');
		var arrow_width = arrow.width();
	
		arrow.css('left', (item_pos.left + item_width / 2 - (arrow_width / 2)) + 'px');
		arrow.css('display', 'block');
	}
}

// Ready the search box
base.readySearch = function() {
	var text = 'Search';
	
	// Clear and re-populate
	$('#input-search').bind({
		focus: function() {
			if ($(this).val() == text) {
				$(this).val('');
				$(this).css('font-style', 'normal');
				$(this).css('color', '#333');
			}
		},
		blur: function() {
			if ($(this).val() == '') {
				$(this).val(text);
				$(this).css('font-style', 'italic');
				$(this).css('color', '#ccc');
			}
		}
	})
	
	// Enter key submits form
	$('#input-search').keypress(function(e) {
		if (e.which == 13) {
			// Handle empty searches for WP
			if ($(this).val() == '') {
				$(this).val(' ');
			}
			$('#form-search').submit();
			e.preventDefault();
		}
	});	
}

// Ensure step box items are clickable
base.readyStepLinks = function() {
	if (page_id != 'home' && page_id != 'gomobile') return false;

	 $('.box-steps li').click(function(e) {
		console.log('clicked');
		if(page_id == 'home') {
			window.location.href = $(this).find('a').attr('href');
		} else {
			$(this).find('a').trigger('click');
		}
	});
}

// Prep the accordion
base.readyAccordion = function() {
	$('.accordion').accordion({
		active: base.getAccordionActiveElement(),
		autoHeight: false
	});
	
	// Set the active link text
	base.setAccordionActiveLinkText();
};

// Ensure FAQ questions are clickable
base.readyFAQs = function() {
	$('.faqs dt').bind('click', function(e) {
		var description = $(this).next('dd');
		if (description.css('display') == 'none') {
			description.fadeIn('slow');
		} else {
			description.hide();
		}
	});
}

// Applies 'smooth scrolling' to anchor tags
base.readySmoothScrolling = function() {
	$('a').each(function(i) {
		if($(this).attr('href').charAt(0) ==  '#'){
			$(this).click(function() {
				  var elementClicked = $(this).attr("href");
				  var destination = $(elementClicked).offset().top;
				  $("html:not(:animated),body:not(:animated)").animate({ scrollTop: destination}, 1500 );
				  return false;
			});
		}
	});
}

// Get latest tweets
base.getTweets = function() {

	// Latest tweet from @ubuntuappdev
	var args = {
		username: 'ubuntuappdev',
		template: '{text}{time}',
		count: 1
	}
	$('.tweet').tweet(args);
}

/* Non-init methods */

// Get the current page ID
base.getPageId = function() {
	return $('body').attr('class');
};

// Get the active accordion element by parsing the URL
base.getAccordionActiveElement = function() {
	var element = 0;
	var current_page_lookup = $('.accordion .current_page_item a');
	if (current_page_lookup.length < 1) {
		return element;
	}
	var url = $('.accordion .current_page_item a')[0].toString();
	var strings = $('.accordion h3 a').map(function(i, elem) {
	   var lookup = elem.toString();
	   return lookup;
	}).get();
	
	// Look for a channel filter and compare it to the accordion headings
	$.each(strings, function(i, string) {
		var pattern = new RegExp(string.replace(/\s+/g, '-').replace('+', 'p'), 'i');
		if (url == string || url.match(pattern)) {
			element = i;
		}
	});
	
	return element;
}

// Set the accordion active link text
base.setAccordionActiveLinkText = function() {
	var active_link = $('.accordion .current_page_item a');
	var link_text = active_link.text();
	active_link.text(link_text + '  ›');
}
